@@ -1,8 +1,10 @@
 from abc import ABC, abstractmethod
 from functools import partial
-from typing import Callable, Self, Iterable, Optional, Sized, Protocol
+from typing import Self, Any, Iterable, Tuple, Optional, Callable, Sized
 
-from pyhandling.annotations import Checker
+from pyannotating import many_or_one
+
+from pyhandling.annotations import checker
 
 
 class IChecker(ABC):
@@ -13,15 +15,15 @@ class IChecker(ABC):
     """
 
     @abstractmethod
-    def __or__(self, other: Checker) -> Self:
+    def __or__(self, other: checker) -> Self:
         pass
 
     @abstractmethod
-    def __and__(self, other: Checker) -> Self:
+    def __and__(self, other: checker) -> Self:
         pass
 
     @abstractmethod
-    def __call__(self, resource: any) -> bool:
+    def __call__(self, resource: Any) -> bool:
         pass
 
 
@@ -31,7 +33,7 @@ class CheckerKeeper:
     unlimited input arguments.
     """
 
-    def __init__(self, checker_resource: Checker | Iterable[Checker], *checkers: Checker):
+    def __init__(self, checker_resource: many_or_one[checker], *checkers: checker):
         self.checkers = (
             tuple(checker_resource)
             if isinstance(checker_resource, Iterable)
@@ -50,19 +52,19 @@ class UnionChecker(CheckerKeeper, IChecker):
 
     def __init__(
         self,
-        checker_resource: Checker | Iterable[Checker],
-        *checkers: Checker,
+        checker_resource: many_or_one[checker],
+        *checkers: checker,
         is_strict: bool = False
     ):
         super().__init__(checker_resource, *checkers)
         self.is_strict = is_strict
 
     @property
-    def checkers(self) -> tuple[Checker]:
+    def checkers(self) -> Tuple[checker]:
         return self._checkers
 
     @checkers.setter
-    def checkers(self, checkers: Iterable[Checker]) -> None:
+    def checkers(self, checkers: Iterable[checker]) -> None:
         self._checkers = tuple(checkers)
 
         if len(self._checkers) == 0:
@@ -76,28 +78,28 @@ class UnionChecker(CheckerKeeper, IChecker):
             )
         )
 
-    def __call__(self, resource: any) -> bool:
+    def __call__(self, resource: Any) -> bool:
         return (all if self.is_strict else any)(
             checker(resource) for checker in self.checkers
         )
 
-    def __or__(self, other: Checker) -> Self:
+    def __or__(self, other: checker) -> Self:
         return self.create_merged_checker_by(self, other, is_strict=False)
 
-    def __ror__(self, other: Checker) -> Self:
+    def __ror__(self, other: checker) -> Self:
         return self.create_merged_checker_by(other, self, is_strict=False)
 
-    def __and__(self, other: Checker) -> Self:
+    def __and__(self, other: checker) -> Self:
         return self.create_merged_checker_by(self, other, is_strict=True)
 
-    def __rand__(self, other: Checker) -> Self:
+    def __rand__(self, other: checker) -> Self:
         return self.create_merged_checker_by(other, self, is_strict=True)
 
     @classmethod
     def create_merged_checker_by(
         cls, 
-        first_checker: Checker, 
-        second_checker: Checker, 
+        first_checker: checker, 
+        second_checker: checker, 
         *args, 
         is_strict: Optional[bool] = None, 
         **kwargs
@@ -127,7 +129,7 @@ class UnionChecker(CheckerKeeper, IChecker):
         )
 
     @staticmethod
-    def __get_checkers_from(checker: Checker) -> Iterable[Checker]:
+    def __get_checkers_from(checker: checker) -> Iterable[checker]:
         return (
             checker.checkers
             if isinstance(checker, UnionChecker)
@@ -146,35 +148,35 @@ class CheckerUnionDelegatorMixin:
     Uses UnionChecker by default.
     """
 
-    _non_strict_union_checker_factory: Callable[[Iterable[Checker]], IChecker] = UnionChecker
-    _strict_union_checker_factory: Callable[[Iterable[Checker]], IChecker] = partial(
+    _non_strict_union_checker_factory: Callable[[Iterable[checker]], IChecker] = UnionChecker
+    _strict_union_checker_factory: Callable[[Iterable[checker]], IChecker] = partial(
         UnionChecker,
         is_strict=True
     )
 
-    def __or__(self, other: Checker) -> IChecker:
+    def __or__(self, other: checker) -> IChecker:
         return self._non_strict_union_checker_factory((self, other))
 
-    def __ror__(self, other: Checker) -> Self:
+    def __ror__(self, other: checker) -> Self:
         return self._non_strict_union_checker_factory((other, self))
 
-    def __and__(self, other: Checker) -> IChecker:
+    def __and__(self, other: checker) -> IChecker:
         return self._strict_union_checker_factory((self, other))
 
-    def __rand__(self, other: Checker) -> Self:
+    def __rand__(self, other: checker) -> Self:
         return self._strict_union_checker_factory((other, self))
 
 
 class Negationer(CheckerUnionDelegatorMixin, IChecker):
     """Proxy checker class to emulate the \"not\" operator."""
 
-    def __init__(self, checker: Checker):
+    def __init__(self, checker: checker):
         self.checker = checker
 
     def __repr__(self) -> str:
         return f"<not {self.checker}>"
 
-    def __call__(self, resource: any) -> bool:
+    def __call__(self, resource: Any) -> bool:
         return not self.checker(resource)
 
 
@@ -188,7 +190,7 @@ class TypeChecker(CheckerUnionDelegatorMixin, IChecker):
 
     def __init__(
         self,
-        correct_type_resource: Iterable[type] | type,
+        correct_type_resource: many_or_one[type],
         *,
         is_correctness_under_supertype: bool = False
     ):
@@ -210,7 +212,7 @@ class TypeChecker(CheckerUnionDelegatorMixin, IChecker):
             )
         )
 
-    def __call__(self, resource: any) -> bool:
+    def __call__(self, resource: Any) -> bool:
         return (
             len(self.correct_types) > 0
             and (all if self.is_correctness_under_supertype else any)(
@@ -232,7 +234,7 @@ class LengthChecker(CheckerUnionDelegatorMixin, IChecker):
     value of the is_end_inclusive attribute.
     """
 
-    def __init__(self, required_length: int | Iterable[int], *, is_end_inclusive: bool = True):
+    def __init__(self, required_length: many_or_one[int], *, is_end_inclusive: bool = True):
         self._required_length = tuple(
             (min(required_length), max(required_length))
             if isinstance(required_length, Iterable)
@@ -242,7 +244,7 @@ class LengthChecker(CheckerUnionDelegatorMixin, IChecker):
         self._update_required_length_range()
 
     @property
-    def required_length(self) -> tuple[int]:
+    def required_length(self) -> Tuple[int]:
         return self._required_length
 
     @required_length.setter
